#
# spec file for package greetd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
  %define _pam_confdir %{_pam_vendordir}
  %define _config_norepl %nil
%else
  %define _pam_confdir %{_sysconfdir}/pam.d
  %define _config_norepl %config(noreplace)
%endif

Name:           greetd
Version:        0.10.3
Release:        2.1
Summary:        Minimal and flexible login manager daemon
License:        GPL-3.0-only
Group:          System/X11/Displaymanagers
URL:            https://git.sr.ht/~kennylevinsen/greetd
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source3:        greetd.pam
Source99:       greetd.rpmlintrc
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  make
BuildRequires:  pam-devel
# Required for man pages
BuildRequires:  scdoc
BuildRequires:  sed
BuildRequires:  systemd-rpm-macros
Requires:       pam
# requires branding
# NOTE: unversioned branding is required to avoid issues like bsc#1205950
Requires:       %{name}-branding

%description
greetd is a login manager daemon. greetd on its own does not have any user interface,
but instead offloads that to greeters, which are arbitrary applications that implement the greetd IPC protocol.

%package agreety
Summary:        A text-based greeter for greetd
Group:          System/X11/Displaymanagers
Requires:       %{name} = %{version}

%description agreety
agreety is a very simple text-based greeter, with an appearance similar to agetty and login.

%package        fakegreet
Group:          Development/Tools/Other
Summary:        Test utility for greeter development

%description    fakegreet
fakegreet is a test utility that allows launching greeters without greetd daemon.

%package branding-upstream
Summary:        Upstream branding of %{name}
Group:          System/X11/Displaymanagers
Requires:       %{name} = %{version}
Requires:       %{name}-agreety = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: /etc/greetd/config.toml contains upstream config

%description branding-upstream
This package provides the upstream look and feel for greetd.

%prep
%autosetup -a1

%build
%{cargo_build}
%make_build -C man

%install

install -D -p -m 0755 target/release/%{name}   %{buildroot}%{_bindir}/%{name}
install -D -p -m 0755 target/release/agreety   %{buildroot}%{_bindir}/agreety
install -D -p -m 0755 target/release/fakegreet %{buildroot}%{_bindir}/fakegreet

%make_install PREFIX=%{_prefix} -C man

# Provide a working default shell for the stock greetd config
# https://github.com/openSUSE/openSUSEway/issues/37
sed -i -e "s|\$SHELL|bash|" config.toml
install -D -p -m 0644 config.toml %{buildroot}/%{_sysconfdir}/%{name}/config.toml

install -D -m 0644 %{name}.service %{buildroot}/%{_unitdir}/%{name}.service

install -D -m 0644 %{SOURCE3} %{buildroot}/%{_pam_confdir}/greetd

install -d %{buildroot}%{_localstatedir}/cache/greetd
install -d %{buildroot}%{_sharedstatedir}/greetd
install -d %{buildroot}/run/greetd

%check
%{cargo_test}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun_without_restart %{name}.service

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%_config_norepl %{_pam_confdir}/greetd
%ghost %attr(711,root,greeter) %dir /run/greetd/
%attr(750,greeter,greeter) %dir %{_sharedstatedir}/greetd
%ghost %dir %{_localstatedir}/cache/greetd/
%{_mandir}/man1/greetd.1*
%{_mandir}/man5/greetd.5*
%{_mandir}/man7/greetd-ipc.7*

%files agreety
%license LICENSE
%{_bindir}/agreety
%{_mandir}/man1/agreety.1*

%files fakegreet
%license LICENSE
%{_bindir}/fakegreet

%files branding-upstream
%license LICENSE
%dir %{_sysconfdir}/%{name}
%attr(644,greeter,greeter) %config(noreplace) %{_sysconfdir}/%{name}/config.toml

%changelog
* Thu Feb  6 2025 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Split off upstream branding into greetd-branding-upstream package
- Split off agreety into greetd-agreety package
- Split off fakegreet into greetd-fakegreet package
- Package manpages
- Adjust package Group to System/X11/Displaymanagers
- Add greetd.rpmlintrc
* Fri Jun  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.10.3:
  * fixes an incorrect cast in the PAM ffi code that could lead
    to periodic failures.
- Update to 0.10.2:
  * fixes builds on stable rust toolchains
  * greetd_ipc: Only set feature flag for docsrs
* Thu Jun  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.10.1:
  * Reintroduce the XDG_VTNR environment variable which some X11
    sessions were relying on
  * context: Error on unexpected auth message response
  * greetd: Scramble response texts after use
  * greetd_ipc: Fix docs.rs build
  * greetd_ipc: Show required codec features in docs
* Thu May 23 2024 Richard Rahl <rrahl0@disroot.org>
- create /var/lib/greetd by default
* Tue May  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Move PAM to /usr -- Fixes filelist-forbidden-move-to-usr badness
- Enable tests
- Service to use manual instead of deprecated disabled
- Remove deprecated cargo_config (now part of vendor)
- Update to version 0.10.0:
  Breaking:
  * Support for the old configuration format, superseded in 0.5.0,
    has been removed. Please ensure that the new INI format
    documented in `man 5 greetd` is used before upgrading.
  * Support for falling back to the `login` PAM service when the
    `greetd` PAM service is missing has been removed. Ensure that a
    `greetd` PAM service is present in `/etc/pam.d/` or
    `/usr/lib/pam.d` before upgrading. The file for `login` can be
    copied if the fallback was used previously.
  * Fewer environment variables are exposed to user sessions. In
    particular, GREETD_SOCK is only shown to greeter sessions, and
    XDG_SESSION_CLASS and XDG_VTNR is only shown to PAM.
  Other:
  * Update deprecated SPDX identifier for GPL-3.0-only
  * Add ReGreet to list of known greetd greeters
  * Drop unmaintained `users` crate
  * Remove no-op question mark and Ok()
  * Remove references that are implicitly dereferenced
  * Remove pointless copying of string before copying it
  * Use strip_prefix to strip prefix
  * Derive VtSelection::default
  * Deduplicate parsing of VtSelection
  * Allow overriding VT via arguments
  * agreety: Return error if no input when prompted
  * config: Fix tests for service config
  * server: cargo fmt
  * pam: Remove fallback to the login service
  * pam: Swap /etc/pam.d and /usr/lib/pam.d
  * man: Document VT switch
  * readme: Add two greeter implementations
  * readme: Add Phog greeter implementation
* Wed Feb  7 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Remove dependencies getent, groupadd, useradd, group(video), now taken care
  of in system-user-greeter
- Remove stale dependency diffutils
* Tue Feb  6 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Do not create greeter user, rely on system-user-greeter
* Mon Jan 30 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.9.0:
  * Revert "Remove 'env' from start_session"
  * ipc: ensure backward compatibility of the protocol
  * Change order of setting pam environment variables
  * fakegreet: reset state on errors
  * For FUSE-based home folders, chdir into them as the user instead of root
  * Use /bin/sh instead of $SHELL
  * cargo: Update dependencies
* Tue Aug  2 2022 llyyr <llyyr.public@gmail.com>
- Put greetd.pam in the right directory.
  greetd checks for the pam file in /etc/pam.d/, not in /lib/pam.d/
* Wed May 25 2022 William Brown <william.brown@suse.com>
- Update vendored dependencies
- Correct ordering of _service entries due to a recompress confusion
* Wed Mar 23 2022 Franck Bui <fbui@suse.com>
- spec: /etc/pam.d/greetd should be %%config(noreplace) on SLE
* Mon Mar 14 2022 Franck Bui <fbui@suse.com>
- spec: don't directly use %%{_distconfdir}, it's broken on SLE
  We should instead make use of %%_pam_vendordir but its definition is also
  broken on SLE... hence let define our own macro for now.
* Fri Jan  7 2022 William Brown <william.brown@suse.com>
- resolve bsc#1194119 (CVE-2021-45710)
* Sun Oct 24 2021 Denys Kondratenko <stdden@opensuse.org>
- Version bump to 0.8.0
  * deps: update tokio to 1.0
  * deps: update nix and other dependencies
  * Ensure initial session is only run once.
  * recommend making config world readable rather than setting owner
  * Update lock file
  * readme: Add discuss section
  * docs: Fix scdoc syntax for greetd.5
  * rustfmt: Change merge_imports to imports_granularity
  * ipc: Fix tokio codec
  * Add makefile for man pages
  * greetd: add terminal switch flag configuration option
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Mon May 17 2021 Denys Kondratenko <stdden@opensuse.org>
- provide real shell in example conf
  * fixes # https://github.com/openSUSE/openSUSEway/issues/37
* Tue Mar 23 2021 Michal Hrusecky <michal.hrusecky@opensuse.org>
- avoid restarts on update by using %%service_del_postun_without_restart
* Sat Jan 30 2021 Andrés Barrantes Silman <andresbs@opensuse.org>
- Version bump to 0.7.0
  * Use additional pam service config for greeter
  * greetd: Added tuigreet to known greeters list.
  * terminal: Use direct open, proper errors
  * worker: Unconditionally set up tty
  * terminal: Forcibly take terminal
  * session: Do not log pam_conv after start
  * ci: Build both arch and alpine
  * Use per-pid socket paths
  * Terminate cleanly on SIGINT
  * Use stdin as VT for current/none vt selections
  * config: Skip reading config in session worker
  * config: Add general.source_profile
  * config: Fix tests for general section
  * docs: Document new general section
  * ci: Disable automatic github mirroring
  * Add installation instructions on Gentoo
  * Make sure to require codec in tokio-codec feature
* Thu Nov  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- add missed group requirement (issue could be seen during installation)
- correct home directory for the greeter user
* Tue Sep 15 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- fix /etc/greetd dir permissions
- relocate pam file to /usr/etc
* Wed Sep  9 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- add missing state and run dirs
* Wed Sep  9 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- fix file permissions to correct greeter user
* Tue Sep  8 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add greetd.pam file and fixed directory permission in etc
* Mon Sep  7 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Initial v0.6.1 greetd package
  * includes greetd service
  * includes agreety text-based greeter
